Computation times — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# Computation times

01:35.378 total execution time for 4 files from examples03-fermi2d:

Example | Time | Mem (MB)
--- | --- | ---
Plotting rashba spin splitting (`plot_rashba_spin_spliting.py`) | 01:03.790 | 0.0
Plotting fermi2d noncolinear (`plot_fermi2d_spin_texture.py`) | 00:15.049 | 0.0
Plotting with Configurations in pyprocar (`plot_fermi2d_configurations.py`) | 00:14.125 | 0.0
Plotting fermi2d (`plot_fermi2d.py`) | 00:02.414 | 0.0